﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2017 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HEAL.Attic;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Parameters;

namespace HeuristicLab.Analysis.FitnessLandscape {
  [Item("Path-Relinking Problem Instance Analyzer", "Tries to identify the current problem instance being solved by analyzing the output of path-relinking heuristics.")]
  [StorableType("DF0066FA-022A-465E-95EE-1D829B471423")]
  public abstract class PrProblemInstanceAnalyzer<T> : ProblemInstanceAnalyzer where T : class, IDeepCloneable {

    [Storable]
    private ILookupParameter<DirectedPath<T>> pathsParameter;
    public ILookupParameter<DirectedPath<T>> PathsParameter {
      get { return pathsParameter; }
    }

    [StorableConstructor]
    protected PrProblemInstanceAnalyzer(StorableConstructorFlag _) : base(_) { }
    protected PrProblemInstanceAnalyzer(PrProblemInstanceAnalyzer<T> original, Cloner cloner)
      : base(original, cloner) {
      pathsParameter = cloner.Clone(original.pathsParameter);
    }
    public PrProblemInstanceAnalyzer() {
      Parameters.Add(pathsParameter = new LookupParameter<DirectedPath<T>>("RelinkedPaths", ""));
    }
  }
}
